@@ -1,5 +1,6 @@
 #include <QtDebug>
 #include <QtGui/QApplication>
+#include <QtGui/QDialogButtonBox>
 #include <QFile>
 #include <QLibraryInfo>
 #include <QLocale>
@@ -25,7 +26,7 @@ void customMessageHandler(QtMsgType type, const char *msg)
                 txt = QString("Fatal: %1").arg(msg);
         }
 
-        QFile outFile("/opt/profilechangerwidget/profilechangerwidget.log");
+        QFile outFile(PCW_APP_LOGFILE);
         outFile.open(QIODevice::WriteOnly | QIODevice::Append);
         QTextStream ts(&outFile);
         ts << txt << endl;
@@ -68,7 +69,7 @@ int main(int argc, char *argv[])
     res = pcwTranslator.load("profilechangerwidget_" + QLocale::system().name(), "/opt/profilechangerwidget");
     app.installTranslator(&pcwTranslator);
     qDebug() << "Translator profilechangerwidget_ sucess=" << res;
-    qDebug() << "Translate Done to " << QApplication::translate("QDialogButtonBox", "Done");
+    qDebug() << "Translate Done to " << QDialogButtonBox::tr("Done");
 
     ProfileChangerWidget w;
 
