@@ -107,7 +107,7 @@ void ProfileChangerWidget::switchProfile() {
 
 void ProfileChangerWidget::onChangeProfileClicked() {
     this->usageCounter++;
-    if(this->usageCounter > PCW_APP_USAGE_LIMIT) {
+    if(this->usageCounter >= PCW_APP_USAGE_LIMIT) {
         this->usageCounter = 0;
         if(PCW_APP_DEVEL) {
             QString tmpInfo;
